<?php

namespace App\Forms;

use Nette,
	Nette\Application\UI\Form,
	App\Model\EventManager,
	App\Presenters\EventPresenter;


class EventFormFactory extends Nette\Object
{
	/** @var EventManager */
	private $eventManager;			
	
	public function __construct(EventManager $eventManager)
	{
		$this->eventManager = $eventManager;
	}


	/**
	 * @return Form
	 */
	 
	public function create()
	{
		$layouts = $this->eventManager->getLayouts();
		$templates = $this->eventManager->getTemplates();
				
		$form = new Form;
		
		$form->addText('event_name', 'Event name:')
			->setAttribute('placeholder', 'Event name')
			->setRequired("Please enter event's name.");
			
		$form->addText('kind', 'Kind:')
			->setAttribute('placeholder', 'Event kind')
			->setRequired("Please select event's kind.");
			
		$form->addTextarea('description', "Event\xc2\xa0description:")
			->setAttribute('placeholder', 'Event description');

		$form->addDatePicker('date', 'Date:')
			->setRequired("Please select date of event.");
		
		$form->addText('time', 'Time:')
			->setAttribute('placeholder', 'HH:ii')
			->addRule(Form::PATTERN, 'Invalid time', '((\d)|([0-1]\d)|(2[0-3])):[0-5][0-9]')
			->setRequired("Please select time of event.");
			
		$form->addText('city', 'City/Town:')
			->setAttribute('placeholder', 'City or Town');
			
		$form->addText('street', 'Street:')
			->setAttribute('placeholder', 'Street name');	
			
		$form->addText('house_num', 'House num.:')
			->setAttribute('placeholder', 'House number');
			
		$form->addSelect('layout', 'Layout:')
			->setItems($layouts)
			->setPrompt("--- Event's layout ---");
			
		$form->addCheckbox('vip', "Add\xc2\xa0VIP");

		$form['layout']->addConditionOn($form['vip'], Form::EQUAL, TRUE)
			->setRequired('You have select layout first, if you want to add VIP seats.');

		$form->addSelect('template', 'Template:')
			->setItems($templates)
			->setPrompt("--- Ticket's template ---");
			
		$form->addHidden('id');
		
		// UPDATE		
		if (isset($_GET['edit']) || !empty($_POST['id'])){
			if(isset($_GET['edit'])){
				$form['id']->setValue($_GET['edit']);
				
				$event = $this->eventManager->getData($_GET['edit']);
				$address = $this->eventManager->getAddress($_GET['edit']);
				$kind = $this->eventManager->getKind($event['events_kind_id']);
				get_object_vars($event['events_date']);
				$form->setDefaults(array(
					'event_name' => $event['events_name'],
					'description' => $event['events_description'],
					'kind' => $kind['kinds_name'],
					'layout' => $event['events_seats_layout_id'],
					'template' => $event['events_tickets_template_id'],
					'date' => date('Y-m-d', strtotime($event['events_date']->date)),
					'time' => date('H:i', strtotime($event['events_time']->h.':'.$event['events_time']->i)),
					'city' => $address['address_city'],
					'street' => $address['address_street'],
					'house_num' => $address['address_house_num']
				));
				$form['layout']->setAttribute('onclick', 'layoutWarning(event)');
			}
			
			$form['vip']->setDisabled(true);
			$form->addSubmit('send', 'Update event');
		} else {
			$form['date']->setValue(date('Y-m-d'));
			$form->addSubmit('send', 'Create event');
		} 
		
		$form->onSuccess[] = array($this, 'formSucceeded');
		return $form;

	}


	public function formSucceeded($form, $values)
	{
		try {
			if(!empty($values->id)){
				$this->eventManager->edit($values, $values->id);
			} else {
				$this->eventManager->add($values);
			}
		} catch (\Exception $e) {
			$form->addError($e->getMessage());	
		}
	}

}
