<?php

namespace App\Forms;

use Nette,
	Nette\Application\UI\Form,
	Nette\Security\User;


class SignFormFactory extends Nette\Object
{
	/** @var User */
	private $user;


	public function __construct(User $user)
	{
		$this->user = $user;
	}


	/**
	 * @return Form
	 */
	public function create()
	{
		$form = new Form;
		
		$form->addText('username')
			->setAttribute('placeholder', 'Username')
			->setRequired('Please enter your username.');

		$form->addPassword('password')
			->setAttribute('placeholder', 'Password')
			->setRequired('Please enter your password.');

		$form->addSubmit('send', 'Sign in');
		
		$form->addCheckbox('remember', 'Remember me');

		$form->onSuccess[] = array($this, 'formSucceeded');
		return $form;
	}


	public function formSucceeded($form, $values)
	{
		if ($values->remember) {
			$this->user->setExpiration(0, FALSE);
		} else {
			$this->user->setExpiration('120 minutes', TRUE);
		}

		try {
			$this->user->login($values->username, $values->password);
		} catch (Nette\Security\AuthenticationException $e) {
			$form->addError($e->getMessage());  
		}
	}

}
