<?php

namespace App\Forms;

use Nette,
	Nette\Application\UI\Form,
	Nette\Security\User,
	App\Model\LayoutManager,
	Nette\Utils\Strings;


class UploadFormFactory extends Nette\Object
{
	/** @var LayoutManager */
	private $layoutManager;			
	
	public function __construct(LayoutManager $layoutManager)
	{
		$this->layoutManager = $layoutManager;
	}


	/**
	 * @return Form
	 */
	public function create()
	{
		$form = new Form;
		
		$form->addText('name')
			->setAttribute('placeholder', 'Layout name')
			->setRequired('You have to enter layout name.');
			
		$form->addUpload('image');
		
		$form->addHidden('id');

		if (isset($_GET['edit'])) {	
			$form['id']->setValue($_GET['edit']);
		}

		$form->addSubmit('submit', 'Save layout');
		
		$form->onSuccess[] = array($this, 'formSucceeded');
		return $form;
	}


	public function formSucceeded($form, $values)
	{
		try {
			if ($values->image->isOk()) {
				$duplicate = 0;
				if (empty($values->id)) {
					$duplicate = $this->layoutManager->controlLayout($values->name);	
				}	
				if ($duplicate === 0) {
					$filename = Strings::webalize(Strings::lower($values->name));
				    $targetPath = "images/seats_layout";
				    $values->image->move("$targetPath/$filename".".jpg");
				    if (!empty($values->id)) {
				    	$this->layoutManager->editLayout($values->name, $filename, $values->id);
				    } else {
						$this->layoutManager->addLayout($values->name, $filename);	
					}
				} else {
					$form->addError("The layout ".$values->name." already exists. Please choose different name.");	
				}	
			} else {
				$form->addError("No image was uploaded. Please try it again.");			
			}	
		} catch (\Exception $e) {
			$form->addError($e->getMessage());	
		}
	}

}
