<?php

namespace App\Model;

use Nette,
	Nette\Utils\ArrayHash;


/**
 * Config management.
 */
class ConfigManager extends Nette\Object
{

	/** @var Nette\Database\Context */
	private $database;


	public function __construct(Nette\Database\Context $database)
	{
		$this->database = $database;
	}


	/**
	 * Adds role.
	 * @param  array
	 * @return void
	 * @throws Exception
	 */
	public function add($values)
	{

		try {
			$bit = 0;

			foreach ($values as $bit_p => $checked) {
				if ($checked == 1) {
					$bit = $bit + $bit_p;
				}
			}

			$this->database->table('roles')->insert(array(
				'roles_name' => $values->name,
				'roles_permissions' => $bit
			));
		} catch (\Exception $e) {
			throw new \Exception($e);	
		}
	}

	
	/**
	 * Updates role's permissions.
	 * @param  array
	 * @param  int
	 * @return void
	 * @throws Exception
	 */
	public function edit($values, $id)
	{
		$bit = 0;

		foreach ($values as $bit_p => $checked) {
			if ($checked == 1) {
				$bit = $bit + $bit_p;
			}
		}

		try {
			$this->database->table('roles')->where('id_roles', $id)->update(array(				 
				'roles_permissions' => $bit,
				'roles_name' => $values->name
			));
		} catch (\Exception $e) {
			throw new \Exception($e);	
		}
	}


	/**
	 * Load permissions.
	 * @return array
	 * @throws Exception
	 */
	public function load()
	{
		try {
			$permissions = $this->database->table('permissions')->select('id_permissions, permissions_name')->fetchPairs('id_permissions', 'permissions_name');	        
		} catch (\Exception $e) {
			throw new \Exception($e);	
		}

		return $permissions;
	}


	/**
	 * Gets permissions.
	 * @param  int
	 * @return array
	 * @throws Exception
	 */
	public function getRolesPermissions($id)
	{
		$permissions = array();

		try {
			$roles_permissions = $this->database->query("
                SELECT permissions.id_permissions, permissions.permissions_name  
                FROM roles LEFT JOIN permissions ON roles.roles_permissions & permissions.id_permissions
                WHERE roles.id_roles = ?
            ", $id)->fetchPairs();	

            $role = $this->database->table('roles')->get($id);

            $permissions[0] = $roles_permissions;
            $permissions['name'] = $role->roles_name;
	        
		} catch (\Exception $e) {
			throw new \Exception($e);	
		}

		return $permissions;
	}


	/**
	 * Deletes roles.
	 * @param  int
	 * @return void
	 * @throws Exception
	 */
	public function delete($id)
	{
		try {
			$this->database->table('roles')->get($id)->update(array(
				'roles_is_active' => 0
			));
		} catch (\Exception $e) {
			throw new \Exception($e);	
		}
	}	


	/**
	 * Selects data for report.
	 * @param string
	 * @param string
	 * @param string
	 */
	public function report($type, $from, $to)
	{
		switch ($type) {
			case 'last_month':
				$from = date("Y-m-d", strtotime("first day of previous month"));
				$to = date("Y-m-d", strtotime("last day of previous month"));
				break;
			
			case 'current_month':
				$from = date("Y-m-d", strtotime("first day of this month"));
				$to = date("Y-m-d", strtotime("today"));
				break;

			case 'date_range':
				break;
		}

		$rows = $this->database->query("
			SELECT tickets_sales_time, events_name, events_date, events_time, seats_name, tickets_code, tickets_price, users_name, dealers_name
			FROM tickets
			JOIN seats ON id_seats = tickets_seats_id
			JOIN events ON id_events = tickets_events_id
			JOIN users ON id_users = tickets_users_id
			JOIN dealers ON id_dealers = users_dealers_id
			WHERE DATE(tickets_sales_time) >= ? AND DATE(tickets_sales_time) <= ?
		", $from, $to)->fetchAll();

		$data = array();
		foreach ($rows as $key => $row) {
			array_push($data, iterator_to_array($row));
			foreach ($row as $name => $value) {
				switch ($name) {
					case 'tickets_sales_time':
					case 'events_date':
						$data[$key][$name] = $value->format("d.m.Y");
						break;
					case 'events_time':
						$data[$key][$name] = $value->h.':'.$value->i;
						break;
				}
			}
		}

		return $data;
	}


	/**
	 * Updates currency. 
	 * @param string
	 */
	public function editCurrency($value) {
		$this->database->table('sale')->where('id_sale', 1)->update(array(
			'sale_currency' => $value
		));
	}


	/**
	 * Gets currency. 
	 * @return string
	 */
	public function getCurrency() {
		return $this->database->table('sale')->select('sale_currency')->fetch();
	}


}