<?php

namespace App\Model;

use Nette,
	Nette\Utils\ArrayHash,
	Nette\Security\Passwords;


/**
 * Mobile management.
 */
class MobileManager extends Nette\Object
{

	/** @var Nette\Database\Context */
	private $database;


	public function __construct(Nette\Database\Context $database)
	{
		$this->database = $database;
	}


	/**
	 * Performs an authentication.
	 * @return array
	 */
	public function login($username, $password)
	{
		$row = $this->database->query("
				SELECT users.*, dealers_is_active
				FROM users
				JOIN dealers ON users_dealers_id = id_dealers
				WHERE users_name = ?
			", $username)->fetch();

		if (!$row || !Passwords::verify($this->decrypt($password, "1234567890987654"), $row['users_password'])) {
			return ['error' => 'Wrong username or password'];

		} elseif ($row->users_is_active === 0) {
			return ['error' => 'Your account was disabled'];

		} elseif ($row->dealers_is_active === 0) {
			return ['error' => 'Your dealer was disabled'];

		} elseif (Passwords::needsRehash($row['users_password'])) {
			$row->update(array(
				'users_password' => Passwords::hash($password),
			));
		}

		unset($row['users_password']);

		$this->database->table('logging')->insert(array(
			'logging_users_id' => $row['id_users'],
			'logging_time' => date('Y-m-d h:i:s', time())
		));

		return ['users_id' => $row['id_users']];
	}

	public static function decrypt($sStr, $sKey) {
		$decrypted= mcrypt_decrypt(
			MCRYPT_RIJNDAEL_128,
			$sKey, 
			base64_decode($sStr), 
			MCRYPT_MODE_ECB
		);
		$dec_s = strlen($decrypted); 
		$padding = ord($decrypted[$dec_s-1]); 
		$decrypted = substr($decrypted, 0, -$padding);
		return $decrypted;
	}

	/**
	 * Checks if ticket is valid
	 */
	public function checkTicket($code)
	{
		$validation = $this->database->table('tickets')->select('tickets_state, tickets_used_time')->where('tickets_code', $code)->fetch();
			
		if (!isset($validation->tickets_state)){
			return ['error' => 'Not found!'];
		}

		if ($validation->tickets_state == "used") {
			return ['error' => "Already used!\nTime: ".$validation->tickets_used_time->format('Y/m/d h:i')];
		} 

		$this->database->table('tickets')->where('tickets_code', $code)->update(array(
			'tickets_state' => 'used',
			'tickets_used_time' => date('Y-m-d h:i:s', time())
		));
		return ['message' => 'Valid!'];
	}

}