<?php

namespace App\Presenters;

use Nette,
	Nextras,
	App\Forms\SaleFormFactory,
	App\Forms\EventFormFactory,
	App\Forms\VipFormFactory,
	App\Model\EventManager;


/**
 * Event presenter.
 */
class EventPresenter extends BasePresenter
{
	/** @var EventManager @inject */	
	public $eventManager;
	
	/** @var SaleFormFactory @inject */
	public $saleForm;
	
	/** @var EventFormFactory @inject */
	public $eventForm;
	
    /** @var VipFormFactory @inject */
	public $vipForm;
	

	public function beforeRender()
	{
		parent::beforeRender();
	}


	/**
	 * Events DataGrid
	 */
	 public function createComponentEventDataGrid()
	 {	
		$grid = new Nextras\Datagrid\Datagrid;
		$grid->addColumn('events_name', 'Name')->enableSort($grid::ORDER_DESC);
		$grid->addColumn('events_description', 'Description')->enableSort();
		$grid->addColumn('kinds_name', 'Kind')->enableSort();
		$grid->addColumn('events_date', 'Date')->enableSort();
		$grid->addColumn('events_time', 'Time')->enableSort();
		
		$grid->setFilterFormFactory(function() {
			$form = new Nette\Forms\Container;
			$form->addText('events_name');
			$form->addText('events_description');
			$form->addText('kinds_name');
			$form->addText('events_date')
				->setType('date');
			$form->addText('events_time')
				->setType('time');
							
			return $form;
		});
		
		$grid->setDataSourceCallBack(function($filter, $order) {
			$filters = array();
		    foreach ($filter as $k => $v) {
		        if ($k == 'events_date' || $k == 'events_time' || is_array($v))
		            $filters[$k] = $v;
		        else
		            $filters[$k. ' LIKE ?'] = "%$v%";
		    }
			
		    $selection = $this->database->table('events')->where('events_is_active', '1')->where($filters)->select('id_events, events_name, events_description, events_date, events_time, kind.kinds_name, events_seats_layout_id, events_tickets_template_id');

		    return $selection;
		}); 
		
		
		$grid->addCellsTemplate(__DIR__ .'/templates/Event/@cells.latte');
		
		return $grid;
	 }


	/**
	 * Deletes event.
	 */
	 public function handleDelete($id){
	 	$this->eventManager->delete($id);
	 }


	/**
	 * Updates event.
	 */
	 public function handleEdit($id){		
		$this->redirect('Event:create', array('edit' => $id));
	 }
	 
	 
	/**
	 * Redirect to sales page.
	 */
	 public function handleSale($id){		
		$this->redirect('Event:sale', $id);
	 }
	 
	 
	/**
	 * Renders sales page.
	 */
	 public function renderSale($event_id){
	 	$this->template->event = $this->eventManager->getSale($event_id);
	 }


	 /**
	 * Redirect to vip page.
	 */
	 public function handleVip($event_id){		
		$this->redirect('Event:vip', $event_id);
	 }


	/**
	 * Renders vip page.
	 */
	 public function renderVip($event_id){
	 	$this->template->event = $this->eventManager->getSale($event_id);
	 }

	 
	 
	/**
	 * Adds form for creating/editing event.
	 * @return Nette\Application\UI\Form
	 */
	protected function createComponentEventForm()
	{		
		$form = $this->eventForm->create();
		
		$form->onSuccess[] = function ($form) {
			if(!empty($form->getValues()->id)){
			 	$this->flashMessage('The event was updated successfully.');
			 	$this->redirect('Event:');
			} else {
				$id = $this->eventManager->add($form->getValues());
				if($form->getValues()->vip == true) {
					$this->redirect('Event:vip', array('event_id' => $id));
				} else {
					$this->flashMessage('The event was created successfully.');
					$this->redirect('Event:');
				}
			}
		};
		
		return $form;
	}
	
	
	/**
	 * Adds form for viewing summary or buying tickets.
	 * @return Nette\Application\UI\Form
	 */
	protected function createComponentSaleForm()
	{		
		$form = $this->saleForm->create();
		
		$form->onSuccess[] = function ($form) {
			
		};
		
		return $form;
	}


	/**
	 * Adds form for creating VIP seats.
	 * @return Nette\Application\UI\Form
	 */
	protected function createComponentVipForm()
	{		
		$form = $this->vipForm->create();
		
		$form->onSuccess[] = function ($form) {
			$this->flashMessage('VIP seats were created successfully.');
			$this->redirect('Event:');
		};
		
		return $form;
	}
	
	
	/**
	 * Tickets DataGrid
	 */
	public function createComponentTicketDataGrid()
	{	
		$grid = new Nextras\Datagrid\Datagrid;
		$grid->addColumn('tickets_code', 'Code')->enableSort();
		$grid->addColumn('tickets_state', 'State')->enableSort();
		$grid->addColumn('tickets_price', 'Price')->enableSort();
		$grid->addColumn('tickets_sales_time', 'Time')->enableSort();
		$grid->addColumn('users_name', 'User')->enableSort();
		$grid->addColumn('events_name', 'Event')->enableSort();
		$grid->addColumn('seats_name', 'Seat')->enableSort();
		
		$grid->setFilterFormFactory(function() {
			$form = new Nette\Forms\Container;
			$form->addText('tickets_code');
			$form->addSelect('tickets_state', NULL, array('unused' => 'unused', 'used' => 'used'))
				->setPrompt('---------------');
			$form->addText('tickets_price');
			$form->addText('tickets_sales_time')
				->setType('date');
			$form->addText('users_name');
			$form->addText('events_name');
			$form->addText('seats_name');
							
			return $form;
		});
		
		$grid->setDataSourceCallBack(function($filter, $order) {
			$filters = array();
		    foreach ($filter as $k => $v) {
		        if ($k == 'tickets_state' || is_array($v))
		            $filters[$k] = $v;
		        else
		            $filters[$k. ' LIKE ?'] = "%$v%";
		    }
			
		    $selection = $this->database->table('tickets')->where($filters)->select('tickets_code, tickets_state, tickets_price, tickets_sales_time, events.events_name, users.users_name, seats.seats_name');

		    return $selection;
		}); 
		
		
		$grid->addCellsTemplate(__DIR__ .'/templates/Event/@ticketcells.latte');
		
		return $grid;
	 }


	/*
	 * Collects data for ticket printing
	 */	 
	public function renderPrint()
	{
	 	$section = $this->getSession('ticket');
		$this->template->html_temp = $this->eventManager->ticketPrint($section->json, $section->event_id);
		unset($section->json);
		unset($section->event_id);
	}
	 
	 
	/*
	 * Blocks seats so they can't be selected by others.
	 */
	public function handleBlock($id)
	{
		$this->eventManager->ticketBlock($id, $this->getParameter('event_id'));	  
	}
	  
	 
	/*
	 * Unblocks seats so they can be on sale again
	 */
	public function handleUnblock($seats_id)
	{
		$this->eventManager->ticketUnblock($seats_id, $this->getParameter('event_id'));	  
	}


	/*
	 * Unblocks all seats after page refresh
	 */
	public function handleUnblockRefresh($json, $event_id)
	{
		$this->eventManager->ticketUnblockRefresh($json, $this->getParameter('event_id'));	  
	}


	/*
	 * Reserves tickets
	 */
	public function handleReserve($json)
	{
		$code = $this->eventManager->reserveTickets($json, $this->getParameter('event_id'));
		echo "Your reservation code: <h1>".$code."</h1>";
		$this->terminate();
	}


	/*
	 * Collects reservations data
	 */
	public function handleCheckReservation($code, $event_id)
	{
		echo $this->eventManager->checkReservation($code, $this->getParameter('event_id'));	   
		$this->terminate();
	}
	 
}