<?php

namespace App\Presenters;

use Nette,
	Nextras,
	App\Model,
	Nette\Security\User,
	App\Forms\ZoneFormFactory,
	App\Forms\UploadFormFactory,
	App\Forms\TemplateFormFactory,
	App\Model\LayoutManager,
	Nette\Utils\Strings;


/**
 * Layout presenter.
 */
class LayoutPresenter extends BasePresenter
{
	/** @var LayoutManager @inject */
	public $layoutManager;
	
	/** @var ZoneFormFactory @inject */
	public $zoneForm;
	
	/** @var UploadFormFactory @inject */
	public $uploadForm;
	
	/** @var TemplateFormFactory @inject */
	public $templateForm;

	
	public function beforeRender()
	{
		parent::beforeRender();
	}


	/**
	 * Layouts DataGrid
	 */
	 public function createComponentLayoutDataGrid()
	 {
		$grid = new Nextras\Datagrid\Datagrid;
		$grid->addColumn('seats_layout_name', 'Name')->enableSort($grid::ORDER_DESC);
		
		$grid->setFilterFormFactory(function() {
			$form = new Nette\Forms\Container;
			$form->addText('seats_layout_name');
			
			return $form;
		});
		
		$grid->setDataSourceCallBack(function($filter, $order) {
			$filters = array();
		    foreach ($filter as $k => $v) {
		    	$filters[$k. ' LIKE ?'] = "%$v%";
		    }
			
			$selection = $this->database->table('seats_layout')->where($filters)->where('seats_layout_is_active', 1)->select('id_seats_layout, seats_layout_name');
		    
		    return $selection;
		});
		
		
		$grid->addCellsTemplate(__DIR__ .'/templates/Layout/@layoutcells.latte');
		
		return $grid;
	 }
	
	
	/**
	 * Deletes layouts.
	 */
	 public function handleDelete($id){
	 	$this->layoutManager->deleteLayout($id);
	 }


	/**
	 * Updates layouts.
	 */
	 public function handleEdit($id){
	 	$this->redirect('Layout:create-layout', array('edit' => $id));
	 }
	
	
	/**
	 * Adds form for uploading zones.
	 * @return Nette\Application\UI\Form
	 */
	protected function createComponentZoneForm()
	{	
		$form = $this->zoneForm->create();
		
		$form->onSuccess[] = function ($form) {
			$this->flashMessage('The zones layout was created successfully.');
			$this->template->upload = false;
			$this->redirect('Layout:');
		};
		
		return $form;
	}
	
	
	/**
	 * Adds form for uploading layout.
	 * @return Nette\Application\UI\Form
	 */
	protected function createComponentUploadForm()
	{	
		$form = $this->uploadForm->create();
		
		$form->onSuccess[] = function ($form) {
			 $this->template->upload = true;
			 $this->template->image = Strings::webalize(Strings::lower($form->values->name));;
			 if(!empty($form->getValues()->id)){
			 	$this->template->id = $form->getValues()->id;
			 }
		};
				
		return $form;
	}
	
	
	/**
	 * Templates DataGrid
	 */
	 public function createComponentTemplateDataGrid()
	 {
		$grid = new Nextras\Datagrid\Datagrid;
		$grid->addColumn('tickets_template_name', 'Name')->enableSort();
		
		$grid->setFilterFormFactory(function() {
			$form = new Nette\Forms\Container;
			$form->addText('tickets_template_name');
			
			return $form;
		});
		
		$grid->setDataSourceCallBack(function($filter, $order) {
			$filters = array();
		    foreach ($filter as $k => $v) {
		    	$filters[$k. ' LIKE ?'] = "%$v%";
		    }
			
		    $selection = $this->database->table('tickets_template')->where('tickets_template_is_active', 1)->where($filters)->select('id_tickets_template, tickets_template_name');

		    return $selection;
		});
		
		
		$grid->addCellsTemplate(__DIR__ .'/templates/Layout/@templatecells.latte');
		
		return $grid;
	 }


	/**
	 * Adds form for creating new ticket template.
	 * @return Nette\Application\UI\Form
	 */
	protected function createComponentTemplateForm()
	{	
		$form = $this->templateForm->create();
		
		$form->onSuccess[] = function ($form) {
			if(!empty($form->getValues()->id)){
			 	$this->flashMessage('The template was updated successfully.');
			} else {
				$this->flashMessage('The template was created successfully.');
			}
			$this->redirect('Layout:');
		};
				
		return $form;
	}
	
	
	/**
	 * Deletes template.
	 */
	 public function handleDeleteTemp($id){
	 	$this->layoutManager->deleteTemplate($id);
	 }


	/**
	 * Updates template.
	 */
	 public function handleEditTemp($id){
	 	$this->redirect('Layout:createTemplate', array('edit' => $id));
	 }
	
}
