<?php

namespace App\Presenters;

use Nette,
	Nextras,
	App\Forms\UserFormFactory,
	App\Model\UserManager;


/**
 * User presenter.
 */
class UserPresenter extends BasePresenter
{
	/** @var UserManager @inject */	
	public $userManager;
	
	/**  @var UserFormFactory @inject */
	public $userForm;
	
	
	public function beforeRender()
	{
		parent::beforeRender();
	}
	

	/**
	 * Users DataGrid
	 */
	 public function createComponentUserDataGrid()
	 {
		$grid = new Nextras\Datagrid\Datagrid;
		$grid->addColumn('users_name', 'Username')->enableSort($grid::ORDER_DESC);
		$grid->addColumn('users_description', 'Description')->enableSort();
		$grid->addColumn('dealers_name', 'Dealer')->enableSort();
		
		$grid->setFilterFormFactory(function() {
			$form = new Nette\Forms\Container;
			$form->addText('users_name');
			$form->addText('users_description');
			$form->addText('dealers_name');
			
			return $form;
		});
		
		$grid->setDataSourceCallBack(function($filter, $order) {
			$filters = array();
		    foreach ($filter as $k => $v) {
		        if ($k == 'id' || is_array($v))
		            $filters[$k] = $v;
		        else
		            $filters[$k. ' LIKE ?'] = "%$v%";
		    }
			
		    $selection = $this->database->table('users')->where('users_is_removed', '0')->where($filters)->select('id_users, users_name, users_description, dealers.dealers_name, users_is_active');

		    return $selection;
		});
		
		
		$grid->addCellsTemplate(__DIR__ .'/templates/User/@cells.latte');
		
		return $grid;
	 }


	/**
	 * Deletes user.
	 */
	 public function handleDelete($id){
	 	$this->userManager->delete($id);
	 }


	/**
	 * Updates user.
	 */
	 public function handleEdit($id){
		$this->redirect('User:create', array('edit' => $id));
	 }
	 

	/**
	 * Adds form for creating/editing user.
	 * @return Nette\Application\UI\Form
	 */
	protected function createComponentUserForm()
	{		
		$form = $this->userForm->create();
		
		$form->onSuccess[] = function ($form) {
			if(!empty($form->getValues()->id)){
			 	$this->flashMessage('The user was updated successfully.');
			} else {
				$this->flashMessage('The user was created successfully.');
			}
			$this->redirect('User:');
		};
		
		return $form;
	}

	
	
}
