-- Adminer 4.2.1 MySQL dump

SET NAMES utf8;
SET time_zone = '+00:00';
SET foreign_key_checks = 0;
SET sql_mode = 'NO_AUTO_VALUE_ON_ZERO';

CREATE DATABASE `test` /*!40100 DEFAULT CHARACTER SET utf8 */;
USE `test`;

DELIMITER ;;

DROP PROCEDURE IF EXISTS `test_multi_sets`;;
CREATE PROCEDURE `test_multi_sets`()
    DETERMINISTIC
begin
        select user() as first_col;
        select user() as first_col, now() as second_col;
        select user() as first_col, now() as second_col, now() as third_col;
        end;;

DELIMITER ;

DROP TABLE IF EXISTS `address`;
CREATE TABLE `address` (
  `id_address` int(5) NOT NULL AUTO_INCREMENT,
  `address_city` varchar(100) NOT NULL,
  `address_street` varchar(100) NOT NULL,
  `address_house_num` varchar(100) NOT NULL,
  PRIMARY KEY (`id_address`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `address` (`id_address`, `address_city`, `address_street`, `address_house_num`) VALUES
(1,	'',	'',	''),
(14,	'Prague',	'Kolovratská',	'2'),
(27,	'Prague',	'Kolovratská',	'2');

DROP TABLE IF EXISTS `dealers`;
CREATE TABLE `dealers` (
  `id_dealers` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `dealers_name` varchar(128) NOT NULL DEFAULT '',
  `dealers_is_active` tinyint(1) NOT NULL,
  `dealers_credit` int(11) NOT NULL DEFAULT '0',
  `dealers_infinite_credit` int(1) NOT NULL DEFAULT '0',
  `dealers_email` varchar(128) DEFAULT NULL,
  `dealers_address_id` int(5) DEFAULT NULL,
  PRIMARY KEY (`id_dealers`),
  UNIQUE KEY `dealers_name` (`dealers_name`),
  KEY `dealers_address_id` (`dealers_address_id`),
  CONSTRAINT `dealers_ibfk_1` FOREIGN KEY (`dealers_address_id`) REFERENCES `address` (`id_address`) ON DELETE SET NULL ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `dealers` (`id_dealers`, `dealers_name`, `dealers_is_active`, `dealers_credit`, `dealers_infinite_credit`, `dealers_email`, `dealers_address_id`) VALUES
(5,	'Default',	1,	39,	0,	'default_dealer@dealer.com',	1);

DROP TABLE IF EXISTS `events`;
CREATE TABLE `events` (
  `id_events` int(11) NOT NULL AUTO_INCREMENT,
  `events_name` varchar(100) NOT NULL,
  `events_description` text NOT NULL,
  `events_kind_id` int(2) DEFAULT NULL,
  `events_date` date NOT NULL,
  `events_time` time NOT NULL,
  `events_address_id` int(5) DEFAULT NULL,
  `events_is_active` tinyint(4) NOT NULL DEFAULT '1',
  `events_tickets_template_id` int(11) DEFAULT NULL,
  `events_seats_layout_id` int(11) DEFAULT NULL,
  `events_seats_layout_events_min` int(11) DEFAULT NULL,
  `events_seats_layout_events_max` int(11) DEFAULT NULL,
  PRIMARY KEY (`id_events`),
  UNIQUE KEY `events_name` (`events_name`),
  KEY `address_id` (`events_address_id`),
  KEY `kind_id` (`events_kind_id`),
  KEY `events_tickets_template_id` (`events_tickets_template_id`),
  KEY `events_zones_group_id` (`events_seats_layout_id`),
  CONSTRAINT `events_ibfk_1` FOREIGN KEY (`events_address_id`) REFERENCES `address` (`id_address`) ON DELETE SET NULL ON UPDATE CASCADE,
  CONSTRAINT `events_ibfk_4` FOREIGN KEY (`events_kind_id`) REFERENCES `kinds` (`id_kinds`) ON DELETE SET NULL ON UPDATE CASCADE,
  CONSTRAINT `events_ibfk_5` FOREIGN KEY (`events_tickets_template_id`) REFERENCES `tickets_template` (`id_tickets_template`) ON DELETE NO ACTION ON UPDATE CASCADE,
  CONSTRAINT `events_ibfk_7` FOREIGN KEY (`events_seats_layout_id`) REFERENCES `seats_layout` (`id_seats_layout`) ON DELETE NO ACTION ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `events` (`id_events`, `events_name`, `events_description`, `events_kind_id`, `events_date`, `events_time`, `events_address_id`, `events_is_active`, `events_tickets_template_id`, `events_seats_layout_id`, `events_seats_layout_events_min`, `events_seats_layout_events_max`) VALUES
(11,	'Example',	'Minions from Despicable Me!',	1,	'2015-10-08',	'17:45:00',	14,	1,	1,	41,	3153,	3412);

DROP TABLE IF EXISTS `kinds`;
CREATE TABLE `kinds` (
  `id_kinds` int(2) NOT NULL AUTO_INCREMENT,
  `kinds_name` varchar(15) NOT NULL,
  PRIMARY KEY (`id_kinds`),
  UNIQUE KEY `kind` (`kinds_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `kinds` (`id_kinds`, `kinds_name`) VALUES
(1,	'Cinema'),
(2,	'Theatre');

DROP TABLE IF EXISTS `logging`;
CREATE TABLE `logging` (
  `id_logging` int(11) NOT NULL AUTO_INCREMENT,
  `logging_users_id` int(11) NOT NULL,
  `logging_time` datetime NOT NULL,
  PRIMARY KEY (`id_logging`),
  KEY `logging_user_id` (`logging_users_id`),
  CONSTRAINT `logging_ibfk_1` FOREIGN KEY (`logging_users_id`) REFERENCES `users` (`id_users`) ON DELETE NO ACTION ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `menu`;
CREATE TABLE `menu` (
  `id_menu` int(2) NOT NULL AUTO_INCREMENT,
  `menu_item` varchar(20) NOT NULL,
  `menu_link` varchar(20) NOT NULL,
  `menu_image` varchar(10) NOT NULL,
  PRIMARY KEY (`id_menu`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `menu` (`id_menu`, `menu_item`, `menu_link`, `menu_image`) VALUES
(1,	'home',	'homepage',	'config'),
(2,	'users',	'user',	'user'),
(3,	'dealers',	'dealer',	'user'),
(4,	'events',	'event',	'ticket'),
(5,	'layouts',	'layout',	'seat'),
(6,	'config',	'config',	'config'),
(7,	'tickets',	'ticket',	'ticket');

DROP TABLE IF EXISTS `permissions`;
CREATE TABLE `permissions` (
  `id_permissions` int(11) NOT NULL AUTO_INCREMENT,
  `permissions_name` varchar(50) NOT NULL,
  PRIMARY KEY (`id_permissions`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `permissions` (`id_permissions`, `permissions_name`) VALUES
(1,	'New User'),
(2,	'Edit User'),
(4,	'Delete User'),
(8,	'New Dealer'),
(16,	'Edit Dealer'),
(32,	'Delete Dealer'),
(64,	'New Event'),
(128,	'Edit Event'),
(256,	'Delete Event'),
(512,	'New Layout'),
(1024,	'Edit Layout'),
(2048,	'Delete Layout'),
(4096,	'New Template'),
(8192,	'Edit Template'),
(16384,	'Delete Template'),
(32768,	'Sale'),
(65536,	'Search'),
(131072,	'Roles'),
(262144,	'Credit'),
(524288,	'Sale VIP'),
(1048576,	'Reports');

DROP TABLE IF EXISTS `reservations`;
CREATE TABLE `reservations` (
  `id_reservations` int(11) NOT NULL AUTO_INCREMENT,
  `reservations_code` varchar(5) NOT NULL,
  `reservations_time` datetime NOT NULL,
  `reservations_users_Id` int(11) NOT NULL,
  `reservations_events_id` int(11) NOT NULL,
  `reservations_is_active` tinyint(4) NOT NULL DEFAULT '1',
  PRIMARY KEY (`id_reservations`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `reservations_seats`;
CREATE TABLE `reservations_seats` (
  `id_reservations_seats` int(11) NOT NULL AUTO_INCREMENT,
  `reservations_seats_reservations_id` int(11) NOT NULL,
  `reservations_seats_seats_id` int(11) NOT NULL,
  `reservations_seats_seats_price` decimal(8,3) NOT NULL,
  `was_buyed` tinyint(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id_reservations_seats`),
  KEY `reservations_seats_reservation_id` (`reservations_seats_reservations_id`),
  KEY `reservations_seats_seats_id` (`reservations_seats_seats_id`),
  CONSTRAINT `reservations_seats_ibfk_1` FOREIGN KEY (`reservations_seats_seats_id`) REFERENCES `seats_layout_events` (`seats_layout_events_seats_id`),
  CONSTRAINT `reservations_seats_ibfk_2` FOREIGN KEY (`reservations_seats_reservations_id`) REFERENCES `reservations` (`id_reservations`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `roles`;
CREATE TABLE `roles` (
  `id_roles` int(1) NOT NULL AUTO_INCREMENT,
  `roles_name` varchar(50) NOT NULL,
  `roles_permissions` int(11) DEFAULT NULL,
  `roles_is_active` tinyint(4) NOT NULL DEFAULT '1',
  PRIMARY KEY (`id_roles`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `roles` (`id_roles`, `roles_name`, `roles_permissions`, `roles_is_active`) VALUES
(1,	'Entrance Manager',	65536,	1),
(2,	'Dealer',	557056,	1),
(3,	'Event Manager',	32704,	1),
(4,	'Admin',	2097151,	1);

DROP TABLE IF EXISTS `sale`;
CREATE TABLE `sale` (
  `id_sale` int(11) NOT NULL AUTO_INCREMENT,
  `sale_currency` varchar(6) NOT NULL,
  PRIMARY KEY (`id_sale`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `sale` (`id_sale`, `sale_currency`) VALUES
(1,	'CZK');

DROP TABLE IF EXISTS `seats`;
CREATE TABLE `seats` (
  `id_seats` int(11) NOT NULL AUTO_INCREMENT,
  `seats_name` varchar(6) NOT NULL,
  `seats_price` int(3) NOT NULL,
  `seats_seats_layout_id` int(11) NOT NULL,
  PRIMARY KEY (`id_seats`),
  KEY `seats_seats_layout_id` (`seats_seats_layout_id`),
  CONSTRAINT `seats_ibfk_1` FOREIGN KEY (`seats_seats_layout_id`) REFERENCES `seats_layout` (`id_seats_layout`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `seats` (`id_seats`, `seats_name`, `seats_price`, `seats_seats_layout_id`) VALUES
(2857,	'A1',	90,	40),
(2858,	'A2',	90,	40),
(2859,	'A3',	90,	40),
(2860,	'A4',	90,	40),
(2861,	'A5',	90,	40),
(2862,	'A6',	90,	40),
(2863,	'A7',	90,	40),
(2864,	'A8',	90,	40),
(2865,	'A9',	90,	40),
(2866,	'A9',	90,	40),
(2867,	'A11',	90,	40),
(2868,	'A12',	90,	40),
(2869,	'A13',	90,	40),
(2870,	'A14',	90,	40),
(2871,	'A15',	90,	40),
(2872,	'A16',	90,	40),
(2873,	'A17',	90,	40),
(2874,	'A18',	90,	40),
(2875,	'A19',	90,	40),
(2876,	'A20',	90,	40),
(2877,	'A21',	90,	40),
(2878,	'A22',	90,	40),
(2879,	'A23',	90,	40),
(2880,	'A24',	90,	40),
(2881,	'A25',	90,	40),
(2882,	'A26',	90,	40),
(2883,	'B1',	100,	40),
(2884,	'B2',	100,	40),
(2885,	'B3',	100,	40),
(2886,	'B4',	100,	40),
(2887,	'B5',	100,	40),
(2888,	'B6',	100,	40),
(2889,	'B7',	100,	40),
(2890,	'B8',	100,	40),
(2891,	'B9',	100,	40),
(2892,	'B10',	100,	40),
(2893,	'B11',	100,	40),
(2894,	'B12',	100,	40),
(2895,	'B13',	100,	40),
(2896,	'B14',	100,	40),
(2897,	'B15',	100,	40),
(2898,	'B16',	100,	40),
(2899,	'B17',	100,	40),
(2900,	'B18',	100,	40),
(2901,	'B19',	100,	40),
(2902,	'B20',	100,	40),
(2903,	'B21',	100,	40),
(2904,	'B22',	100,	40),
(2905,	'B23',	100,	40),
(2906,	'B24',	100,	40),
(2907,	'B25',	100,	40),
(2908,	'B26',	100,	40),
(2909,	'C1',	100,	40),
(2910,	'C2',	100,	40),
(2911,	'C3',	100,	40),
(2912,	'C4',	100,	40),
(2913,	'C5',	100,	40),
(2914,	'C6',	100,	40),
(2915,	'C7',	100,	40),
(2916,	'C8',	100,	40),
(2917,	'C9',	100,	40),
(2918,	'C10',	100,	40),
(2919,	'C11',	100,	40),
(2920,	'C12',	100,	40),
(2921,	'C13',	100,	40),
(2922,	'C14',	100,	40),
(2923,	'C15',	100,	40),
(2924,	'C16',	100,	40),
(2925,	'C17',	100,	40),
(2926,	'C18',	100,	40),
(2927,	'C19',	100,	40),
(2928,	'C20',	100,	40),
(2929,	'C21',	100,	40),
(2930,	'C22',	100,	40),
(2931,	'C23',	100,	40),
(2932,	'C24',	100,	40),
(2933,	'C25',	100,	40),
(2934,	'C26',	100,	40),
(2935,	'D0',	0,	40),
(2936,	'D1',	100,	40),
(2937,	'D2',	100,	40),
(2938,	'D3',	100,	40),
(2939,	'D4',	100,	40),
(2940,	'D5',	100,	40),
(2941,	'D6',	100,	40),
(2942,	'D7',	100,	40),
(2943,	'D8',	100,	40),
(2944,	'D9',	100,	40),
(2945,	'D10',	100,	40),
(2946,	'D11',	100,	40),
(2947,	'D0',	0,	40),
(2948,	'D12',	100,	40),
(2949,	'D14',	100,	40),
(2950,	'D15',	100,	40),
(2951,	'D16',	100,	40),
(2952,	'D17',	100,	40),
(2953,	'D18',	100,	40),
(2954,	'D19',	100,	40),
(2955,	'D20',	100,	40),
(2956,	'D21',	100,	40),
(2957,	'D22',	100,	40),
(2958,	'D23',	100,	40),
(2959,	'D24',	100,	40),
(2960,	'D0',	0,	40),
(2961,	'E0',	0,	40),
(2962,	'E0',	0,	40),
(2963,	'E1',	100,	40),
(2964,	'E2',	100,	40),
(2965,	'E3',	100,	40),
(2966,	'E4',	100,	40),
(2967,	'E5',	100,	40),
(2968,	'E6',	100,	40),
(2969,	'E7',	100,	40),
(2970,	'E8',	100,	40),
(2971,	'E9',	100,	40),
(2972,	'E10',	100,	40),
(2973,	'E11',	100,	40),
(2974,	'E12',	100,	40),
(2975,	'E13',	100,	40),
(2976,	'E14',	100,	40),
(2977,	'E15',	100,	40),
(2978,	'E16',	100,	40),
(2979,	'E17',	100,	40),
(2980,	'E18',	100,	40),
(2981,	'E19',	100,	40),
(2982,	'E20',	100,	40),
(2983,	'E21',	100,	40),
(2984,	'E22',	100,	40),
(2985,	'E0',	0,	40),
(2986,	'E0',	0,	40),
(3507,	'A1',	90,	41),
(3508,	'A2',	90,	41),
(3509,	'A3',	90,	41),
(3510,	'A4',	90,	41),
(3511,	'A5',	90,	41),
(3512,	'A6',	90,	41),
(3513,	'A7',	90,	41),
(3514,	'A8',	90,	41),
(3515,	'A9',	90,	41),
(3516,	'A9',	90,	41),
(3517,	'A11',	90,	41),
(3518,	'A12',	90,	41),
(3519,	'A13',	90,	41),
(3520,	'A14',	90,	41),
(3521,	'A15',	90,	41),
(3522,	'A16',	90,	41),
(3523,	'A17',	90,	41),
(3524,	'A18',	90,	41),
(3525,	'A19',	90,	41),
(3526,	'A20',	90,	41),
(3527,	'A21',	90,	41),
(3528,	'A22',	90,	41),
(3529,	'A23',	90,	41),
(3530,	'A24',	90,	41),
(3531,	'A25',	90,	41),
(3532,	'A26',	90,	41),
(3533,	'B1',	100,	41),
(3534,	'B2',	100,	41),
(3535,	'B3',	100,	41),
(3536,	'B4',	100,	41),
(3537,	'B5',	100,	41),
(3538,	'B6',	100,	41),
(3539,	'B7',	100,	41),
(3540,	'B8',	100,	41),
(3541,	'B9',	100,	41),
(3542,	'B10',	100,	41),
(3543,	'B11',	100,	41),
(3544,	'B12',	100,	41),
(3545,	'B13',	100,	41),
(3546,	'B14',	100,	41),
(3547,	'B15',	100,	41),
(3548,	'B16',	100,	41),
(3549,	'B17',	100,	41),
(3550,	'B18',	100,	41),
(3551,	'B19',	100,	41),
(3552,	'B20',	100,	41),
(3553,	'B21',	100,	41),
(3554,	'B22',	100,	41),
(3555,	'B23',	100,	41),
(3556,	'B24',	100,	41),
(3557,	'B25',	100,	41),
(3558,	'B26',	100,	41),
(3559,	'C1',	100,	41),
(3560,	'C2',	100,	41),
(3561,	'C3',	100,	41),
(3562,	'C4',	100,	41),
(3563,	'C5',	100,	41),
(3564,	'C6',	100,	41),
(3565,	'C7',	100,	41),
(3566,	'C8',	100,	41),
(3567,	'C9',	100,	41),
(3568,	'C10',	100,	41),
(3569,	'C11',	100,	41),
(3570,	'C12',	100,	41),
(3571,	'C13',	100,	41),
(3572,	'C14',	100,	41),
(3573,	'C15',	100,	41),
(3574,	'C16',	100,	41),
(3575,	'C17',	100,	41),
(3576,	'C18',	100,	41),
(3577,	'C19',	100,	41),
(3578,	'C20',	100,	41),
(3579,	'C21',	100,	41),
(3580,	'C22',	100,	41),
(3581,	'C23',	100,	41),
(3582,	'C24',	100,	41),
(3583,	'C25',	100,	41),
(3584,	'C26',	100,	41),
(3585,	'D0',	0,	41),
(3586,	'D1',	100,	41),
(3587,	'D2',	100,	41),
(3588,	'D3',	100,	41),
(3589,	'D4',	100,	41),
(3590,	'D5',	100,	41),
(3591,	'D6',	100,	41),
(3592,	'D7',	100,	41),
(3593,	'D8',	100,	41),
(3594,	'D9',	100,	41),
(3595,	'D10',	100,	41),
(3596,	'D11',	100,	41),
(3597,	'D0',	0,	41),
(3598,	'D12',	100,	41),
(3599,	'D14',	100,	41),
(3600,	'D15',	100,	41),
(3601,	'D16',	100,	41),
(3602,	'D17',	100,	41),
(3603,	'D18',	100,	41),
(3604,	'D19',	100,	41),
(3605,	'D20',	100,	41),
(3606,	'D21',	100,	41),
(3607,	'D22',	100,	41),
(3608,	'D23',	100,	41),
(3609,	'D24',	100,	41),
(3610,	'D0',	0,	41),
(3611,	'E0',	0,	41),
(3612,	'E0',	0,	41),
(3613,	'E1',	100,	41),
(3614,	'E2',	100,	41),
(3615,	'E3',	100,	41),
(3616,	'E4',	100,	41),
(3617,	'E5',	100,	41),
(3618,	'E6',	100,	41),
(3619,	'E7',	100,	41),
(3620,	'E8',	100,	41),
(3621,	'E9',	100,	41),
(3622,	'E10',	100,	41),
(3623,	'E11',	100,	41),
(3624,	'E12',	100,	41),
(3625,	'E13',	100,	41),
(3626,	'E14',	100,	41),
(3627,	'E15',	100,	41),
(3628,	'E16',	100,	41),
(3629,	'E17',	100,	41),
(3630,	'E18',	100,	41),
(3631,	'E19',	100,	41),
(3632,	'E20',	100,	41),
(3633,	'E21',	100,	41),
(3634,	'E22',	100,	41),
(3635,	'E0',	0,	41),
(3636,	'E0',	0,	41),
(3637,	'F1',	100,	41),
(3638,	'F2',	100,	41),
(3639,	'F0',	0,	41),
(3640,	'F3',	100,	41),
(3641,	'F4',	100,	41),
(3642,	'F5',	100,	41),
(3643,	'F6',	100,	41),
(3644,	'F7',	100,	41),
(3645,	'F8',	100,	41),
(3646,	'F9',	100,	41),
(3647,	'F10',	100,	41),
(3648,	'F11',	100,	41),
(3649,	'F0',	0,	41),
(3650,	'F0',	0,	41),
(3651,	'F12',	100,	41),
(3652,	'F13',	100,	41),
(3653,	'F14',	100,	41),
(3654,	'F15',	100,	41),
(3655,	'F16',	100,	41),
(3656,	'F17',	100,	41),
(3657,	'F18',	100,	41),
(3658,	'F19',	100,	41),
(3659,	'F20',	100,	41),
(3660,	'F0',	0,	41),
(3661,	'F21',	100,	41),
(3662,	'F22',	100,	41),
(3663,	'G1',	100,	41),
(3664,	'G2',	100,	41),
(3665,	'G0',	0,	41),
(3666,	'G3',	100,	41),
(3667,	'G4',	100,	41),
(3668,	'G5',	100,	41),
(3669,	'G6',	100,	41),
(3670,	'G7',	100,	41),
(3671,	'G8',	100,	41),
(3672,	'G9',	100,	41),
(3673,	'G10',	100,	41),
(3674,	'G11',	100,	41),
(3675,	'G0',	0,	41),
(3676,	'G0',	0,	41),
(3677,	'G12',	100,	41),
(3678,	'G13',	100,	41),
(3679,	'G14',	100,	41),
(3680,	'G15',	100,	41),
(3681,	'G16',	100,	41),
(3682,	'G17',	100,	41),
(3683,	'G18',	100,	41),
(3684,	'G19',	100,	41),
(3685,	'G20',	100,	41),
(3686,	'G0',	0,	41),
(3687,	'G21',	100,	41),
(3688,	'G22',	100,	41),
(3689,	'H1',	100,	41),
(3690,	'H2',	100,	41),
(3691,	'H3',	100,	41),
(3692,	'H4',	100,	41),
(3693,	'H5',	100,	41),
(3694,	'H6',	100,	41),
(3695,	'H9',	115,	41),
(3696,	'H10',	115,	41),
(3697,	'H11',	115,	41),
(3698,	'H12',	115,	41),
(3699,	'H13',	115,	41),
(3700,	'H14',	115,	41),
(3701,	'H0',	0,	41),
(3702,	'H0',	0,	41),
(3703,	'H15',	115,	41),
(3704,	'H16',	115,	41),
(3705,	'H17',	115,	41),
(3706,	'H18',	115,	41),
(3707,	'H19',	115,	41),
(3708,	'H20',	115,	41),
(3709,	'H21',	100,	41),
(3710,	'H22',	100,	41),
(3711,	'H23',	100,	41),
(3712,	'H24',	100,	41),
(3713,	'H25',	100,	41),
(3714,	'H26',	100,	41),
(3715,	'I1',	100,	41),
(3716,	'I2',	100,	41),
(3717,	'I3',	100,	41),
(3718,	'I4',	100,	41),
(3719,	'I5',	100,	41),
(3720,	'I7',	100,	41),
(3721,	'I9',	130,	41),
(3722,	'I10',	130,	41),
(3723,	'I11',	130,	41),
(3724,	'I12',	130,	41),
(3725,	'I13',	130,	41),
(3726,	'I14',	130,	41),
(3727,	'I0',	0,	41),
(3728,	'I0',	0,	41),
(3729,	'I15',	130,	41),
(3730,	'I16',	130,	41),
(3731,	'I17',	130,	41),
(3732,	'I18',	130,	41),
(3733,	'I19',	130,	41),
(3734,	'I20',	130,	41),
(3735,	'I21',	100,	41),
(3736,	'I22',	100,	41),
(3737,	'I23',	100,	41),
(3738,	'I24',	100,	41),
(3739,	'I25',	100,	41),
(3740,	'I26',	100,	41),
(3741,	'J1',	100,	41),
(3742,	'J2',	100,	41),
(3743,	'J3',	100,	41),
(3744,	'J4',	100,	41),
(3745,	'J5',	100,	41),
(3746,	'J8',	100,	41),
(3747,	'J9',	150,	41),
(3748,	'J10',	150,	41),
(3749,	'J11',	150,	41),
(3750,	'J12',	150,	41),
(3751,	'J13',	150,	41),
(3752,	'J14',	150,	41),
(3753,	'J0',	0,	41),
(3754,	'J0',	0,	41),
(3755,	'J15',	150,	41),
(3756,	'J16',	150,	41),
(3757,	'J17',	150,	41),
(3758,	'J18',	150,	41),
(3759,	'J19',	150,	41),
(3760,	'J20',	150,	41),
(3761,	'J21',	100,	41),
(3762,	'J22',	100,	41),
(3763,	'J23',	100,	41),
(3764,	'J24',	100,	41),
(3765,	'J25',	100,	41),
(3766,	'J26',	100,	41);

DROP TABLE IF EXISTS `seats_layout`;
CREATE TABLE `seats_layout` (
  `id_seats_layout` int(11) NOT NULL AUTO_INCREMENT,
  `seats_layout_name` varchar(100) NOT NULL,
  `seats_layout_filename` varchar(100) NOT NULL,
  `seats_layout_is_active` tinyint(4) NOT NULL DEFAULT '1',
  PRIMARY KEY (`id_seats_layout`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `seats_layout` (`id_seats_layout`, `seats_layout_name`, `seats_layout_filename`, `seats_layout_is_active`) VALUES
(40,	'abcd',	'abcd',	1),
(41,	'Example',	'example',	1);

DROP TABLE IF EXISTS `seats_layout_events`;
CREATE TABLE `seats_layout_events` (
  `id_seats_layout_events` int(11) NOT NULL AUTO_INCREMENT,
  `seats_layout_events_seats_id` int(11) NOT NULL,
  `seats_layout_events_available` enum('0','1','VIP_1','VIP_0','0_res','VIP_0_res') NOT NULL DEFAULT '1',
  `seats_layout_events_status` tinyint(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id_seats_layout_events`),
  KEY `seats_layout_events_seats_id` (`seats_layout_events_seats_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `seats_layout_events` (`id_seats_layout_events`, `seats_layout_events_seats_id`, `seats_layout_events_available`, `seats_layout_events_status`) VALUES
(2893,	2987,	'1',	0),
(2894,	2988,	'1',	0),
(2895,	2989,	'1',	0),
(2896,	2990,	'1',	0),
(2897,	2991,	'1',	0),
(2898,	2992,	'1',	0),
(2899,	2993,	'1',	0),
(2900,	2994,	'1',	0),
(2901,	2995,	'1',	0),
(2902,	2996,	'1',	0),
(2903,	2997,	'1',	0),
(2904,	2998,	'1',	0),
(2905,	2999,	'1',	0),
(2906,	3000,	'1',	0),
(2907,	3001,	'1',	0),
(2908,	3002,	'1',	0),
(2909,	3003,	'1',	0),
(2910,	3004,	'1',	0),
(2911,	3005,	'1',	0),
(2912,	3006,	'1',	0),
(2913,	3007,	'1',	0),
(2914,	3008,	'1',	0),
(2915,	3009,	'1',	0),
(2916,	3010,	'1',	0),
(2917,	3011,	'1',	0),
(2918,	3012,	'1',	0),
(2919,	3013,	'1',	0),
(2920,	3014,	'1',	0),
(2921,	3015,	'1',	0),
(2922,	3016,	'1',	0),
(2923,	3017,	'1',	0),
(2924,	3018,	'1',	0),
(2925,	3019,	'1',	0),
(2926,	3020,	'1',	0),
(2927,	3021,	'1',	0),
(2928,	3022,	'1',	0),
(2929,	3023,	'1',	0),
(2930,	3024,	'1',	0),
(2931,	3025,	'1',	0),
(2932,	3026,	'1',	0),
(2933,	3027,	'1',	0),
(2934,	3028,	'1',	0),
(2935,	3029,	'1',	0),
(2936,	3030,	'1',	0),
(2937,	3031,	'1',	0),
(2938,	3032,	'1',	0),
(2939,	3033,	'1',	0),
(2940,	3034,	'1',	0),
(2941,	3035,	'1',	0),
(2942,	3036,	'1',	0),
(2943,	3037,	'1',	0),
(2944,	3038,	'1',	0),
(2945,	3039,	'1',	0),
(2946,	3040,	'1',	0),
(2947,	3041,	'1',	0),
(2948,	3042,	'1',	0),
(2949,	3043,	'1',	0),
(2950,	3044,	'1',	0),
(2951,	3045,	'1',	0),
(2952,	3046,	'1',	0),
(2953,	3047,	'1',	0),
(2954,	3048,	'1',	0),
(2955,	3049,	'1',	0),
(2956,	3050,	'1',	0),
(2957,	3051,	'1',	0),
(2958,	3052,	'1',	0),
(2959,	3053,	'1',	0),
(2960,	3054,	'1',	0),
(2961,	3055,	'1',	0),
(2962,	3056,	'1',	0),
(2963,	3057,	'1',	0),
(2964,	3058,	'1',	0),
(2965,	3059,	'1',	0),
(2966,	3060,	'1',	0),
(2967,	3061,	'1',	0),
(2968,	3062,	'1',	0),
(2969,	3063,	'1',	0),
(2970,	3064,	'1',	0),
(2971,	3065,	'1',	0),
(2972,	3066,	'1',	0),
(2973,	3067,	'1',	0),
(2974,	3068,	'1',	0),
(2975,	3069,	'1',	0),
(2976,	3070,	'1',	0),
(2977,	3071,	'1',	0),
(2978,	3072,	'1',	0),
(2979,	3073,	'1',	0),
(2980,	3074,	'1',	0),
(2981,	3075,	'1',	0),
(2982,	3076,	'1',	0),
(2983,	3077,	'1',	0),
(2984,	3078,	'1',	0),
(2985,	3079,	'1',	0),
(2986,	3080,	'1',	0),
(2987,	3081,	'1',	0),
(2988,	3082,	'1',	0),
(2989,	3083,	'1',	0),
(2990,	3084,	'1',	0),
(2991,	3085,	'1',	0),
(2992,	3086,	'1',	0),
(2993,	3087,	'1',	0),
(2994,	3088,	'1',	0),
(2995,	3089,	'1',	0),
(2996,	3090,	'1',	0),
(2997,	3091,	'1',	0),
(2998,	3092,	'1',	0),
(2999,	3093,	'1',	0),
(3000,	3094,	'1',	0),
(3001,	3095,	'1',	0),
(3002,	3096,	'1',	0),
(3003,	3097,	'1',	0),
(3004,	3098,	'1',	0),
(3005,	3099,	'1',	0),
(3006,	3100,	'1',	0),
(3007,	3101,	'1',	0),
(3008,	3102,	'1',	0),
(3009,	3103,	'1',	0),
(3010,	3104,	'1',	0),
(3011,	3105,	'1',	0),
(3012,	3106,	'1',	0),
(3013,	3107,	'1',	0),
(3014,	3108,	'1',	0),
(3015,	3109,	'1',	0),
(3016,	3110,	'1',	0),
(3017,	3111,	'1',	0),
(3018,	3112,	'1',	0),
(3019,	3113,	'1',	0),
(3020,	3114,	'1',	0),
(3021,	3115,	'1',	0),
(3022,	3116,	'1',	0),
(3023,	3377,	'1',	0),
(3024,	3378,	'1',	0),
(3025,	3379,	'1',	0),
(3026,	3380,	'1',	0),
(3027,	3381,	'1',	0),
(3028,	3382,	'1',	0),
(3029,	3383,	'1',	0),
(3030,	3384,	'1',	0),
(3031,	3385,	'1',	0),
(3032,	3386,	'1',	0),
(3033,	3387,	'1',	0),
(3034,	3388,	'1',	0),
(3035,	3389,	'1',	0),
(3036,	3390,	'1',	0),
(3037,	3391,	'1',	0),
(3038,	3392,	'1',	0),
(3039,	3393,	'1',	0),
(3040,	3394,	'1',	0),
(3041,	3395,	'1',	0),
(3042,	3396,	'1',	0),
(3043,	3397,	'1',	0),
(3044,	3398,	'1',	0),
(3045,	3399,	'1',	0),
(3046,	3400,	'1',	0),
(3047,	3401,	'1',	0),
(3048,	3402,	'1',	0),
(3049,	3403,	'1',	0),
(3050,	3404,	'1',	0),
(3051,	3405,	'1',	0),
(3052,	3406,	'1',	0),
(3053,	3407,	'1',	0),
(3054,	3408,	'1',	0),
(3055,	3409,	'1',	0),
(3056,	3410,	'1',	0),
(3057,	3411,	'1',	0),
(3058,	3412,	'1',	0),
(3059,	3413,	'1',	0),
(3060,	3414,	'1',	0),
(3061,	3415,	'1',	0),
(3062,	3416,	'1',	0),
(3063,	3417,	'1',	0),
(3064,	3418,	'1',	0),
(3065,	3419,	'1',	0),
(3066,	3420,	'1',	0),
(3067,	3421,	'1',	0),
(3068,	3422,	'1',	0),
(3069,	3423,	'1',	0),
(3070,	3424,	'1',	0),
(3071,	3425,	'1',	0),
(3072,	3426,	'1',	0),
(3073,	3427,	'1',	0),
(3074,	3428,	'1',	0),
(3075,	3429,	'1',	0),
(3076,	3430,	'1',	0),
(3077,	3431,	'1',	0),
(3078,	3432,	'1',	0),
(3079,	3433,	'1',	0),
(3080,	3434,	'1',	0),
(3081,	3435,	'1',	0),
(3082,	3436,	'1',	0),
(3083,	3437,	'1',	0),
(3084,	3438,	'1',	0),
(3085,	3439,	'1',	0),
(3086,	3440,	'1',	0),
(3087,	3441,	'1',	0),
(3088,	3442,	'1',	0),
(3089,	3443,	'1',	0),
(3090,	3444,	'1',	0),
(3091,	3445,	'1',	0),
(3092,	3446,	'1',	0),
(3093,	3447,	'1',	0),
(3094,	3448,	'1',	0),
(3095,	3449,	'1',	0),
(3096,	3450,	'1',	0),
(3097,	3451,	'1',	0),
(3098,	3452,	'1',	0),
(3099,	3453,	'1',	0),
(3100,	3454,	'1',	0),
(3101,	3455,	'1',	0),
(3102,	3456,	'1',	0),
(3103,	3457,	'1',	0),
(3104,	3458,	'1',	0),
(3105,	3459,	'1',	0),
(3106,	3460,	'1',	0),
(3107,	3461,	'1',	0),
(3108,	3462,	'1',	0),
(3109,	3463,	'1',	0),
(3110,	3464,	'1',	0),
(3111,	3465,	'1',	0),
(3112,	3466,	'1',	0),
(3113,	3467,	'1',	0),
(3114,	3468,	'1',	0),
(3115,	3469,	'1',	0),
(3116,	3470,	'1',	0),
(3117,	3471,	'1',	0),
(3118,	3472,	'1',	0),
(3119,	3473,	'1',	0),
(3120,	3474,	'1',	0),
(3121,	3475,	'1',	0),
(3122,	3476,	'1',	0),
(3123,	3477,	'1',	0),
(3124,	3478,	'1',	0),
(3125,	3479,	'1',	0),
(3126,	3480,	'1',	0),
(3127,	3481,	'1',	0),
(3128,	3482,	'1',	0),
(3129,	3483,	'1',	0),
(3130,	3484,	'1',	0),
(3131,	3485,	'1',	0),
(3132,	3486,	'1',	0),
(3133,	3487,	'1',	0),
(3134,	3488,	'1',	0),
(3135,	3489,	'1',	0),
(3136,	3490,	'1',	0),
(3137,	3491,	'1',	0),
(3138,	3492,	'1',	0),
(3139,	3493,	'1',	0),
(3140,	3494,	'1',	0),
(3141,	3495,	'1',	0),
(3142,	3496,	'1',	0),
(3143,	3497,	'1',	0),
(3144,	3498,	'1',	0),
(3145,	3499,	'1',	0),
(3146,	3500,	'1',	0),
(3147,	3501,	'1',	0),
(3148,	3502,	'1',	0),
(3149,	3503,	'1',	0),
(3150,	3504,	'1',	0),
(3151,	3505,	'1',	0),
(3152,	3506,	'1',	0),
(3153,	3507,	'1',	0),
(3154,	3508,	'1',	0),
(3155,	3509,	'1',	0),
(3156,	3510,	'1',	0),
(3157,	3511,	'1',	0),
(3158,	3512,	'1',	0),
(3159,	3513,	'1',	0),
(3160,	3514,	'1',	0),
(3161,	3515,	'1',	0),
(3162,	3516,	'1',	0),
(3163,	3517,	'1',	0),
(3164,	3518,	'1',	0),
(3165,	3519,	'1',	0),
(3166,	3520,	'1',	0),
(3167,	3521,	'1',	0),
(3168,	3522,	'1',	0),
(3169,	3523,	'1',	0),
(3170,	3524,	'1',	0),
(3171,	3525,	'1',	0),
(3172,	3526,	'1',	0),
(3173,	3527,	'1',	0),
(3174,	3528,	'1',	0),
(3175,	3529,	'1',	0),
(3176,	3530,	'1',	0),
(3177,	3531,	'1',	0),
(3178,	3532,	'1',	0),
(3179,	3533,	'1',	0),
(3180,	3534,	'1',	0),
(3181,	3535,	'1',	0),
(3182,	3536,	'1',	0),
(3183,	3537,	'1',	0),
(3184,	3538,	'1',	0),
(3185,	3539,	'1',	0),
(3186,	3540,	'1',	0),
(3187,	3541,	'1',	0),
(3188,	3542,	'1',	0),
(3189,	3543,	'1',	0),
(3190,	3544,	'1',	0),
(3191,	3545,	'1',	0),
(3192,	3546,	'1',	0),
(3193,	3547,	'1',	0),
(3194,	3548,	'1',	0),
(3195,	3549,	'1',	0),
(3196,	3550,	'1',	0),
(3197,	3551,	'1',	0),
(3198,	3552,	'1',	0),
(3199,	3553,	'1',	0),
(3200,	3554,	'1',	0),
(3201,	3555,	'1',	0),
(3202,	3556,	'1',	0),
(3203,	3557,	'1',	0),
(3204,	3558,	'1',	0),
(3205,	3559,	'1',	0),
(3206,	3560,	'1',	0),
(3207,	3561,	'1',	0),
(3208,	3562,	'1',	0),
(3209,	3563,	'1',	0),
(3210,	3564,	'1',	0),
(3211,	3565,	'1',	0),
(3212,	3566,	'1',	0),
(3213,	3567,	'1',	0),
(3214,	3568,	'1',	0),
(3215,	3569,	'1',	0),
(3216,	3570,	'1',	0),
(3217,	3571,	'1',	0),
(3218,	3572,	'1',	0),
(3219,	3573,	'1',	0),
(3220,	3574,	'1',	0),
(3221,	3575,	'1',	0),
(3222,	3576,	'1',	0),
(3223,	3577,	'1',	0),
(3224,	3578,	'1',	0),
(3225,	3579,	'1',	0),
(3226,	3580,	'1',	0),
(3227,	3581,	'1',	0),
(3228,	3582,	'1',	0),
(3229,	3583,	'1',	0),
(3230,	3584,	'1',	0),
(3231,	3585,	'1',	0),
(3232,	3586,	'1',	0),
(3233,	3587,	'1',	0),
(3234,	3588,	'1',	0),
(3235,	3589,	'1',	0),
(3236,	3590,	'1',	0),
(3237,	3591,	'1',	0),
(3238,	3592,	'1',	0),
(3239,	3593,	'1',	0),
(3240,	3594,	'1',	0),
(3241,	3595,	'1',	0),
(3242,	3596,	'1',	0),
(3243,	3597,	'1',	0),
(3244,	3598,	'1',	0),
(3245,	3599,	'1',	0),
(3246,	3600,	'1',	0),
(3247,	3601,	'1',	0),
(3248,	3602,	'1',	0),
(3249,	3603,	'1',	0),
(3250,	3604,	'1',	0),
(3251,	3605,	'1',	0),
(3252,	3606,	'1',	0),
(3253,	3607,	'1',	0),
(3254,	3608,	'1',	0),
(3255,	3609,	'1',	0),
(3256,	3610,	'1',	0),
(3257,	3611,	'1',	0),
(3258,	3612,	'1',	0),
(3259,	3613,	'1',	0),
(3260,	3614,	'1',	0),
(3261,	3615,	'1',	0),
(3262,	3616,	'1',	0),
(3263,	3617,	'1',	0),
(3264,	3618,	'1',	0),
(3265,	3619,	'1',	0),
(3266,	3620,	'1',	0),
(3267,	3621,	'1',	0),
(3268,	3622,	'1',	0),
(3269,	3623,	'1',	0),
(3270,	3624,	'1',	0),
(3271,	3625,	'1',	0),
(3272,	3626,	'1',	0),
(3273,	3627,	'1',	0),
(3274,	3628,	'1',	0),
(3275,	3629,	'1',	0),
(3276,	3630,	'1',	0),
(3277,	3631,	'1',	0),
(3278,	3632,	'1',	0),
(3279,	3633,	'1',	0),
(3280,	3634,	'1',	0),
(3281,	3635,	'1',	0),
(3282,	3636,	'1',	0),
(3283,	3637,	'1',	0),
(3284,	3638,	'1',	0),
(3285,	3639,	'1',	0),
(3286,	3640,	'1',	0),
(3287,	3641,	'1',	0),
(3288,	3642,	'1',	0),
(3289,	3643,	'1',	0),
(3290,	3644,	'1',	0),
(3291,	3645,	'1',	0),
(3292,	3646,	'1',	0),
(3293,	3647,	'1',	0),
(3294,	3648,	'1',	0),
(3295,	3649,	'1',	0),
(3296,	3650,	'1',	0),
(3297,	3651,	'1',	0),
(3298,	3652,	'1',	0),
(3299,	3653,	'1',	0),
(3300,	3654,	'1',	0),
(3301,	3655,	'1',	0),
(3302,	3656,	'1',	0),
(3303,	3657,	'1',	0),
(3304,	3658,	'1',	0),
(3305,	3659,	'1',	0),
(3306,	3660,	'1',	0),
(3307,	3661,	'1',	0),
(3308,	3662,	'1',	0),
(3309,	3663,	'1',	0),
(3310,	3664,	'1',	0),
(3311,	3665,	'1',	0),
(3312,	3666,	'1',	0),
(3313,	3667,	'1',	0),
(3314,	3668,	'1',	0),
(3315,	3669,	'1',	0),
(3316,	3670,	'1',	0),
(3317,	3671,	'1',	0),
(3318,	3672,	'1',	0),
(3319,	3673,	'1',	0),
(3320,	3674,	'1',	0),
(3321,	3675,	'1',	0),
(3322,	3676,	'1',	0),
(3323,	3677,	'1',	0),
(3324,	3678,	'1',	0),
(3325,	3679,	'1',	0),
(3326,	3680,	'1',	0),
(3327,	3681,	'1',	0),
(3328,	3682,	'1',	0),
(3329,	3683,	'1',	0),
(3330,	3684,	'1',	0),
(3331,	3685,	'1',	0),
(3332,	3686,	'1',	0),
(3333,	3687,	'1',	0),
(3334,	3688,	'1',	0),
(3335,	3689,	'1',	0),
(3336,	3690,	'1',	0),
(3337,	3691,	'1',	0),
(3338,	3692,	'1',	0),
(3339,	3693,	'1',	0),
(3340,	3694,	'1',	0),
(3341,	3695,	'1',	0),
(3342,	3696,	'1',	0),
(3343,	3697,	'1',	0),
(3344,	3698,	'1',	0),
(3345,	3699,	'1',	0),
(3346,	3700,	'1',	0),
(3347,	3701,	'1',	0),
(3348,	3702,	'1',	0),
(3349,	3703,	'1',	0),
(3350,	3704,	'1',	0),
(3351,	3705,	'1',	0),
(3352,	3706,	'1',	0),
(3353,	3707,	'1',	0),
(3354,	3708,	'1',	0),
(3355,	3709,	'1',	0),
(3356,	3710,	'1',	0),
(3357,	3711,	'1',	0),
(3358,	3712,	'1',	0),
(3359,	3713,	'1',	0),
(3360,	3714,	'1',	0),
(3361,	3715,	'1',	0),
(3362,	3716,	'1',	0),
(3363,	3717,	'1',	0),
(3364,	3718,	'1',	0),
(3365,	3719,	'1',	0),
(3366,	3720,	'1',	0),
(3367,	3721,	'1',	0),
(3368,	3722,	'1',	0),
(3369,	3723,	'1',	0),
(3370,	3724,	'1',	0),
(3371,	3725,	'1',	0),
(3372,	3726,	'1',	0),
(3373,	3727,	'1',	0),
(3374,	3728,	'1',	0),
(3375,	3729,	'1',	0),
(3376,	3730,	'1',	0),
(3377,	3731,	'1',	0),
(3378,	3732,	'1',	0),
(3379,	3733,	'1',	0),
(3380,	3734,	'1',	0),
(3381,	3735,	'1',	0),
(3382,	3736,	'1',	0),
(3383,	3737,	'1',	0),
(3384,	3738,	'1',	0),
(3385,	3739,	'1',	0),
(3386,	3740,	'1',	0),
(3387,	3741,	'1',	0),
(3388,	3742,	'1',	0),
(3389,	3743,	'1',	0),
(3390,	3744,	'1',	0),
(3391,	3745,	'1',	0),
(3392,	3746,	'1',	0),
(3393,	3747,	'1',	0),
(3394,	3748,	'1',	0),
(3395,	3749,	'1',	0),
(3396,	3750,	'1',	0),
(3397,	3751,	'1',	0),
(3398,	3752,	'1',	0),
(3399,	3753,	'1',	0),
(3400,	3754,	'1',	0),
(3401,	3755,	'1',	0),
(3402,	3756,	'1',	0),
(3403,	3757,	'1',	0),
(3404,	3758,	'1',	0),
(3405,	3759,	'1',	0),
(3406,	3760,	'1',	0),
(3407,	3761,	'1',	0),
(3408,	3762,	'1',	0),
(3409,	3763,	'1',	0),
(3410,	3764,	'1',	0),
(3411,	3765,	'1',	0),
(3412,	3766,	'1',	0);

DROP TABLE IF EXISTS `submenu`;
CREATE TABLE `submenu` (
  `id_submenu` int(11) NOT NULL AUTO_INCREMENT,
  `submenu_item` varchar(20) NOT NULL,
  `submenu_menu_id` int(2) NOT NULL,
  `submenu_link` varchar(20) NOT NULL,
  PRIMARY KEY (`id_submenu`),
  KEY `submen_menu_id` (`submenu_menu_id`),
  CONSTRAINT `submenu_ibfk_1` FOREIGN KEY (`submenu_menu_id`) REFERENCES `menu` (`id_menu`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `submenu` (`id_submenu`, `submenu_item`, `submenu_menu_id`, `submenu_link`) VALUES
(1,	'home',	1,	'default'),
(2,	'users',	2,	'default'),
(4,	'dealers',	3,	'default'),
(6,	'events',	4,	'default'),
(8,	'seat layouts',	5,	'default'),
(9,	'tickets',	4,	'ticket'),
(10,	'ticket templates',	5,	'template'),
(11,	'permissions',	6,	'default'),
(12,	'search',	7,	'default'),
(13,	'report',	6,	'report'),
(14,	'sale',	6,	'sale'),
(15,	'simple search',	7,	'simple');

DROP TABLE IF EXISTS `tickets`;
CREATE TABLE `tickets` (
  `id_tickets` int(11) NOT NULL AUTO_INCREMENT,
  `tickets_code` varchar(10) NOT NULL,
  `tickets_seats_id` int(11) NOT NULL,
  `tickets_events_id` int(11) NOT NULL,
  `tickets_sales_time` datetime NOT NULL,
  `tickets_used_time` datetime DEFAULT NULL,
  `tickets_users_id` int(11) NOT NULL,
  `tickets_state` set('used','unused') NOT NULL DEFAULT 'unused',
  `tickets_price` decimal(8,3) NOT NULL,
  `tickets_reservations_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id_tickets`),
  UNIQUE KEY `tickets_code` (`tickets_code`),
  KEY `tickets_events_id` (`tickets_events_id`),
  KEY `tickets_seats_id` (`tickets_seats_id`),
  KEY `tickets_users_id` (`tickets_users_id`),
  KEY `tickets_reservation_id` (`tickets_reservations_id`),
  CONSTRAINT `tickets_ibfk_1` FOREIGN KEY (`tickets_events_id`) REFERENCES `events` (`id_events`) ON DELETE NO ACTION ON UPDATE CASCADE,
  CONSTRAINT `tickets_ibfk_2` FOREIGN KEY (`tickets_seats_id`) REFERENCES `seats` (`id_seats`) ON DELETE NO ACTION ON UPDATE CASCADE,
  CONSTRAINT `tickets_ibfk_3` FOREIGN KEY (`tickets_users_id`) REFERENCES `users` (`id_users`) ON DELETE NO ACTION ON UPDATE CASCADE,
  CONSTRAINT `tickets_ibfk_4` FOREIGN KEY (`tickets_reservations_id`) REFERENCES `reservations` (`id_reservations`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `tickets_template`;
CREATE TABLE `tickets_template` (
  `id_tickets_template` int(11) NOT NULL AUTO_INCREMENT,
  `tickets_template_name` varchar(25) NOT NULL,
  `tickets_template_code` text NOT NULL,
  `tickets_template_is_active` tinyint(4) NOT NULL DEFAULT '1',
  PRIMARY KEY (`id_tickets_template`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `tickets_template` (`id_tickets_template`, `tickets_template_name`, `tickets_template_code`, `tickets_template_is_active`) VALUES
(1,	'test',	'<html>\r\n<head>\r\n<style>\r\n    body {\r\n        font-family: \"Trebuchet MS\", Helvetica, sans-serif;\r\n        width: 300px;\r\n    }\r\n    h1 {\r\n        font-weight: bold;\r\n        font-size: 30px;\r\n        text-transform: uppercase;\r\n    }\r\n    h1,h2,h3{\r\n        padding: 0px;\r\n        margin: 0px;\r\n        color: #3e3e3e\r\n    }\r\n    h2 {\r\n        font-size: 20px;\r\n        text-transform: uppercase;\r\n    }\r\n    h3 {\r\n        font-size: 16px;\r\n        font-variant: small-caps;\r\n    }\r\n    hr {\r\n        background-color: #2d2d2d;\r\n        color: white;\r\n        height: 3px;\r\n    }\r\n    .dotted {\r\n        border-width:5px;	\r\n        border-right-style:dotted;\r\n    }\r\n   table {\r\n        text-align: center;\r\n        width: 100%;\r\n   }\r\n    tr td {\r\n        font-size: 30px; \r\n        padding: 5px;\r\n    }\r\n    div {\r\n        padding: 5px;\r\n        text-align: center;\r\n    }\r\n</style>\r\n</head>\r\n<body>\r\n\r\n    <div>\r\n        <h1>{event}</h1>\r\n        <h2>{kind}</h2>\r\n        <hr />\r\n            <h3>{adress}</h3>\r\n        <hr />\r\n        <table>\r\n            <tr>\r\n                <th class=\"dotted\">SEAT</th>\r\n                <th>DATE</th>\r\n            </tr>\r\n            <tr>\r\n                <td class=\"dotted\">{seat}</td>\r\n                <td>{date}</td>\r\n            </tr>\r\n        </table>\r\n        <hr />\r\n        <h3>Control</h3>\r\n        {bar_code}\r\n        {unique_code}\r\n    </div>\r\n        \r\n</body>\r\n</html>',	1);

DROP TABLE IF EXISTS `users`;
CREATE TABLE `users` (
  `id_users` int(11) NOT NULL AUTO_INCREMENT,
  `users_name` varchar(20) NOT NULL,
  `users_description` varchar(20) DEFAULT NULL,
  `users_is_active` tinyint(1) DEFAULT NULL,
  `users_roles_id` int(1) DEFAULT '1',
  `users_password` varchar(100) NOT NULL,
  `users_dealers_id` int(11) unsigned NOT NULL,
  `users_email` varchar(60) DEFAULT NULL,
  `users_address_id` int(5) DEFAULT NULL,
  PRIMARY KEY (`id_users`),
  UNIQUE KEY `users_name` (`users_name`),
  KEY `users_address_id` (`users_address_id`),
  KEY `users_roles_id` (`users_roles_id`),
  KEY `users_dealers_id` (`users_dealers_id`),
  CONSTRAINT `users_ibfk_5` FOREIGN KEY (`users_dealers_id`) REFERENCES `dealers` (`id_dealers`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `users_ibfk_6` FOREIGN KEY (`users_address_id`) REFERENCES `address` (`id_address`) ON DELETE SET NULL ON UPDATE CASCADE,
  CONSTRAINT `users_ibfk_8` FOREIGN KEY (`users_roles_id`) REFERENCES `roles` (`id_roles`) ON DELETE SET NULL ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `users` (`id_users`, `users_name`, `users_description`, `users_is_active`, `users_roles_id`, `users_password`, `users_dealers_id`, `users_email`, `users_address_id`) VALUES
(40,	'kiki',	'admin',	1,	4,	'$2y$10$MXV54zynDXJTo0SFWiAOrudMe3JkyXlHU6n1iLRxJoXZF/15FjfZu',	5,	'rehovicova@hotmail.com',	NULL),
(71,	'jakub',	'Kuba',	1,	1,	'$2y$10$r/tDPbGxebLeBhdzHNHowO55ZlPSp.dTT0aut6oTdS8WNS2EQcdRu',	5,	'jakub@jacon.cz',	NULL),
(72,	'Zaw',	'',	1,	3,	'$2y$10$Wzq4sJoJjlawjA.0HQfefOiNqNag3vU.O6hr3Jbi7sOGAzSaqhAl2',	5,	'zaw@mail.com',	1),
(73,	'jan',	'Honza',	1,	4,	'$2y$10$X99.HyvWGDse8GF.F.dRHeK6yy9.e1pJwKmfrkTmfKGTo9TObuE1e',	5,	'jan@jacon.cz',	27);

DROP TABLE IF EXISTS `zones`;
CREATE TABLE `zones` (
  `id_zones` int(11) NOT NULL AUTO_INCREMENT,
  `zones_name` varchar(30) NOT NULL,
  `zones_zones_group_id` int(11) NOT NULL,
  `zones_price` decimal(8,3) NOT NULL,
  `zones_coords` varchar(70) NOT NULL,
  `zones_row_seats_num` int(5) NOT NULL,
  PRIMARY KEY (`id_zones`),
  KEY `seats_groups_seats_group_id` (`zones_zones_group_id`),
  CONSTRAINT `zones_ibfk_2` FOREIGN KEY (`zones_zones_group_id`) REFERENCES `zones_group` (`id_zones_group`) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `zones` (`id_zones`, `zones_name`, `zones_zones_group_id`, `zones_price`, `zones_coords`, `zones_row_seats_num`) VALUES
(34,	'reddd',	29,	333.000,	'48,45,640,52,640,134,48,130',	26),
(37,	'blue',	31,	300.000,	'49,149,642,149,642,260,48,259',	26),
(39,	'red',	33,	250.000,	'49,24,642,24,642,135,44,134',	26),
(40,	'blue',	33,	300.000,	'48,151,643,150,643,260,48,261',	26);

DROP TABLE IF EXISTS `zones_group`;
CREATE TABLE `zones_group` (
  `id_zones_group` int(11) NOT NULL AUTO_INCREMENT,
  `zones_group_is_active` tinyint(4) NOT NULL DEFAULT '1',
  PRIMARY KEY (`id_zones_group`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `zones_group` (`id_zones_group`, `zones_group_is_active`) VALUES
(29,	1),
(31,	1),
(33,	1);

DROP TABLE IF EXISTS `zones_seats`;
CREATE TABLE `zones_seats` (
  `id_zones_seats` int(11) NOT NULL AUTO_INCREMENT,
  `zones_seats_zones_id` int(11) NOT NULL,
  `zones_seats_seats_id` int(11) NOT NULL,
  PRIMARY KEY (`id_zones_seats`),
  KEY `zones_id` (`zones_seats_zones_id`),
  KEY `seats_id` (`zones_seats_seats_id`),
  CONSTRAINT `zones_seats_ibfk_1` FOREIGN KEY (`zones_seats_zones_id`) REFERENCES `zones` (`id_zones`),
  CONSTRAINT `zones_seats_ibfk_2` FOREIGN KEY (`zones_seats_seats_id`) REFERENCES `seats` (`id_seats`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `zones_seats` (`id_zones_seats`, `zones_seats_zones_id`, `zones_seats_seats_id`) VALUES
(2851,	34,	2857),
(2852,	34,	2858),
(2853,	34,	2859),
(2854,	34,	2860),
(2855,	34,	2861),
(2856,	34,	2862),
(2857,	34,	2863),
(2858,	34,	2864),
(2859,	34,	2865),
(2860,	34,	2866),
(2861,	34,	2867),
(2862,	34,	2868),
(2863,	34,	2869),
(2864,	34,	2870),
(2865,	34,	2871),
(2866,	34,	2872),
(2867,	34,	2873),
(2868,	34,	2874),
(2869,	34,	2875),
(2870,	34,	2876),
(2871,	34,	2877),
(2872,	34,	2878),
(2873,	34,	2879),
(2874,	34,	2880),
(2875,	34,	2881),
(2876,	34,	2882),
(2877,	34,	2883),
(2878,	34,	2884),
(2879,	34,	2885),
(2880,	34,	2886),
(2881,	34,	2887),
(2882,	34,	2888),
(2883,	34,	2889),
(2884,	34,	2890),
(2885,	34,	2891),
(2886,	34,	2892),
(2887,	34,	2893),
(2888,	34,	2894),
(2889,	34,	2895),
(2890,	34,	2896),
(2891,	34,	2897),
(2892,	34,	2898),
(2893,	34,	2899),
(2894,	34,	2900),
(2895,	34,	2901),
(2896,	34,	2902),
(2897,	34,	2903),
(2898,	34,	2904),
(2899,	34,	2905),
(2900,	34,	2906),
(2901,	34,	2907),
(2902,	34,	2908),
(2903,	34,	2909),
(2904,	34,	2910),
(2905,	34,	2911),
(2906,	34,	2912),
(2907,	34,	2913),
(2908,	34,	2914),
(2909,	34,	2915),
(2910,	34,	2916),
(2911,	34,	2917),
(2912,	34,	2918),
(2913,	34,	2919),
(2914,	34,	2920),
(2915,	34,	2921),
(2916,	34,	2922),
(2917,	34,	2923),
(2918,	34,	2924),
(2919,	34,	2925),
(2920,	34,	2926),
(2921,	34,	2927),
(2922,	34,	2928),
(2923,	34,	2929),
(2924,	34,	2930),
(2925,	34,	2931),
(2926,	34,	2932),
(2927,	34,	2933),
(2928,	34,	2934),
(2929,	34,	2935),
(2930,	34,	2936),
(2931,	34,	2937),
(2932,	34,	2938),
(2933,	34,	2939),
(2934,	34,	2940),
(2935,	34,	2941),
(2936,	34,	2942),
(2937,	34,	2943),
(2938,	34,	2944),
(2939,	34,	2945),
(2940,	34,	2946),
(2941,	34,	2947),
(2942,	34,	2948),
(2943,	34,	2949),
(2944,	34,	2950),
(2945,	34,	2951),
(2946,	34,	2952),
(2947,	34,	2953),
(2948,	34,	2954),
(2949,	34,	2955),
(2950,	34,	2956),
(2951,	34,	2957),
(2952,	34,	2958),
(2953,	34,	2959),
(2954,	34,	2960),
(2955,	34,	2961),
(2956,	34,	2962),
(2957,	34,	2963),
(2958,	34,	2964),
(2959,	34,	2965),
(2960,	34,	2966),
(2961,	34,	2967),
(2962,	34,	2968),
(2963,	34,	2969),
(2964,	34,	2970),
(2965,	34,	2971),
(2966,	34,	2972),
(2967,	34,	2973),
(2968,	34,	2974),
(2969,	34,	2975),
(2970,	34,	2976),
(2971,	34,	2977),
(2972,	34,	2978),
(2973,	34,	2979),
(2974,	34,	2980),
(2975,	34,	2981),
(2976,	34,	2982),
(2977,	34,	2983),
(2978,	34,	2984),
(2979,	34,	2985),
(2980,	34,	2986),
(3501,	39,	3507),
(3502,	39,	3508),
(3503,	39,	3509),
(3504,	39,	3510),
(3505,	39,	3511),
(3506,	39,	3512),
(3507,	39,	3513),
(3508,	39,	3514),
(3509,	39,	3515),
(3510,	39,	3516),
(3511,	39,	3517),
(3512,	39,	3518),
(3513,	39,	3519),
(3514,	39,	3520),
(3515,	39,	3521),
(3516,	39,	3522),
(3517,	39,	3523),
(3518,	39,	3524),
(3519,	39,	3525),
(3520,	39,	3526),
(3521,	39,	3527),
(3522,	39,	3528),
(3523,	39,	3529),
(3524,	39,	3530),
(3525,	39,	3531),
(3526,	39,	3532),
(3527,	39,	3533),
(3528,	39,	3534),
(3529,	39,	3535),
(3530,	39,	3536),
(3531,	39,	3537),
(3532,	39,	3538),
(3533,	39,	3539),
(3534,	39,	3540),
(3535,	39,	3541),
(3536,	39,	3542),
(3537,	39,	3543),
(3538,	39,	3544),
(3539,	39,	3545),
(3540,	39,	3546),
(3541,	39,	3547),
(3542,	39,	3548),
(3543,	39,	3549),
(3544,	39,	3550),
(3545,	39,	3551),
(3546,	39,	3552),
(3547,	39,	3553),
(3548,	39,	3554),
(3549,	39,	3555),
(3550,	39,	3556),
(3551,	39,	3557),
(3552,	39,	3558),
(3553,	39,	3559),
(3554,	39,	3560),
(3555,	39,	3561),
(3556,	39,	3562),
(3557,	39,	3563),
(3558,	39,	3564),
(3559,	39,	3565),
(3560,	39,	3566),
(3561,	39,	3567),
(3562,	39,	3568),
(3563,	39,	3569),
(3564,	39,	3570),
(3565,	39,	3571),
(3566,	39,	3572),
(3567,	39,	3573),
(3568,	39,	3574),
(3569,	39,	3575),
(3570,	39,	3576),
(3571,	39,	3577),
(3572,	39,	3578),
(3573,	39,	3579),
(3574,	39,	3580),
(3575,	39,	3581),
(3576,	39,	3582),
(3577,	39,	3583),
(3578,	39,	3584),
(3579,	39,	3585),
(3580,	39,	3586),
(3581,	39,	3587),
(3582,	39,	3588),
(3583,	39,	3589),
(3584,	39,	3590),
(3585,	39,	3591),
(3586,	39,	3592),
(3587,	39,	3593),
(3588,	39,	3594),
(3589,	39,	3595),
(3590,	39,	3596),
(3591,	39,	3597),
(3592,	39,	3598),
(3593,	39,	3599),
(3594,	39,	3600),
(3595,	39,	3601),
(3596,	39,	3602),
(3597,	39,	3603),
(3598,	39,	3604),
(3599,	39,	3605),
(3600,	39,	3606),
(3601,	39,	3607),
(3602,	39,	3608),
(3603,	39,	3609),
(3604,	39,	3610),
(3605,	39,	3611),
(3606,	39,	3612),
(3607,	39,	3613),
(3608,	39,	3614),
(3609,	39,	3615),
(3610,	39,	3616),
(3611,	39,	3617),
(3612,	39,	3618),
(3613,	39,	3619),
(3614,	39,	3620),
(3615,	39,	3621),
(3616,	39,	3622),
(3617,	39,	3623),
(3618,	39,	3624),
(3619,	39,	3625),
(3620,	39,	3626),
(3621,	39,	3627),
(3622,	39,	3628),
(3623,	39,	3629),
(3624,	39,	3630),
(3625,	39,	3631),
(3626,	39,	3632),
(3627,	39,	3633),
(3628,	39,	3634),
(3629,	39,	3635),
(3630,	39,	3636),
(3631,	40,	3637),
(3632,	40,	3638),
(3633,	40,	3639),
(3634,	40,	3640),
(3635,	40,	3641),
(3636,	40,	3642),
(3637,	40,	3643),
(3638,	40,	3644),
(3639,	40,	3645),
(3640,	40,	3646),
(3641,	40,	3647),
(3642,	40,	3648),
(3643,	40,	3649),
(3644,	40,	3650),
(3645,	40,	3651),
(3646,	40,	3652),
(3647,	40,	3653),
(3648,	40,	3654),
(3649,	40,	3655),
(3650,	40,	3656),
(3651,	40,	3657),
(3652,	40,	3658),
(3653,	40,	3659),
(3654,	40,	3660),
(3655,	40,	3661),
(3656,	40,	3662),
(3657,	40,	3663),
(3658,	40,	3664),
(3659,	40,	3665),
(3660,	40,	3666),
(3661,	40,	3667),
(3662,	40,	3668),
(3663,	40,	3669),
(3664,	40,	3670),
(3665,	40,	3671),
(3666,	40,	3672),
(3667,	40,	3673),
(3668,	40,	3674),
(3669,	40,	3675),
(3670,	40,	3676),
(3671,	40,	3677),
(3672,	40,	3678),
(3673,	40,	3679),
(3674,	40,	3680),
(3675,	40,	3681),
(3676,	40,	3682),
(3677,	40,	3683),
(3678,	40,	3684),
(3679,	40,	3685),
(3680,	40,	3686),
(3681,	40,	3687),
(3682,	40,	3688),
(3683,	40,	3689),
(3684,	40,	3690),
(3685,	40,	3691),
(3686,	40,	3692),
(3687,	40,	3693),
(3688,	40,	3694),
(3689,	40,	3695),
(3690,	40,	3696),
(3691,	40,	3697),
(3692,	40,	3698),
(3693,	40,	3699),
(3694,	40,	3700),
(3695,	40,	3701),
(3696,	40,	3702),
(3697,	40,	3703),
(3698,	40,	3704),
(3699,	40,	3705),
(3700,	40,	3706),
(3701,	40,	3707),
(3702,	40,	3708),
(3703,	40,	3709),
(3704,	40,	3710),
(3705,	40,	3711),
(3706,	40,	3712),
(3707,	40,	3713),
(3708,	40,	3714),
(3709,	40,	3715),
(3710,	40,	3716),
(3711,	40,	3717),
(3712,	40,	3718),
(3713,	40,	3719),
(3714,	40,	3720),
(3715,	40,	3721),
(3716,	40,	3722),
(3717,	40,	3723),
(3718,	40,	3724),
(3719,	40,	3725),
(3720,	40,	3726),
(3721,	40,	3727),
(3722,	40,	3728),
(3723,	40,	3729),
(3724,	40,	3730),
(3725,	40,	3731),
(3726,	40,	3732),
(3727,	40,	3733),
(3728,	40,	3734),
(3729,	40,	3735),
(3730,	40,	3736),
(3731,	40,	3737),
(3732,	40,	3738),
(3733,	40,	3739),
(3734,	40,	3740),
(3735,	40,	3741),
(3736,	40,	3742),
(3737,	40,	3743),
(3738,	40,	3744),
(3739,	40,	3745),
(3740,	40,	3746),
(3741,	40,	3747),
(3742,	40,	3748),
(3743,	40,	3749),
(3744,	40,	3750),
(3745,	40,	3751),
(3746,	40,	3752),
(3747,	40,	3753),
(3748,	40,	3754),
(3749,	40,	3755),
(3750,	40,	3756),
(3751,	40,	3757),
(3752,	40,	3758),
(3753,	40,	3759),
(3754,	40,	3760),
(3755,	40,	3761),
(3756,	40,	3762),
(3757,	40,	3763),
(3758,	40,	3764),
(3759,	40,	3765),
(3760,	40,	3766);

-- 2015-09-22 19:10:27
